@@ -1,7 +1,7 @@
 package Redis::Hash;
 
 # ABSTRACT: tie Perl hashes to Redis hashes
-our $VERSION = '1.961'; # VERSION
+our $VERSION = '1.962'; # VERSION
 our $AUTHORITY = 'cpan:MELO'; # AUTHORITY
 
 use strict;
@@ -65,13 +65,14 @@ sub CLEAR {
 
 1;    ## End of Redis::Hash
 
-__END__
 
+
+__END__
 =pod
 
 =encoding utf-8
 
-=for :stopwords Pedro Melo ACKNOWLEDGEMENTS
+=for :stopwords Pedro Melo Damien Krotkine Melo, ACKNOWLEDGEMENTS
 
 =head1 NAME
 
@@ -79,7 +80,7 @@ Redis::Hash - tie Perl hashes to Redis hashes
 
 =head1 VERSION
 
-version 1.961
+version 1.962
 
 =head1 DESCRIPTION
 
@@ -108,16 +109,27 @@ Future versions will also allow you to use real Redis hash structures.
 
     %my_hash = ();
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Pedro Melo <melo@cpan.org>
 
+=item *
+
+Damien Krotkine <dams@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Pedro Melo.
+This software is Copyright (c) 2013 by Pedro Melo, Damien Krotkine.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
+
